@@ -6,7 +6,8 @@ CardStatus = Literal["Inactive", "Active", "Stolen", "Lost", "Frozen", "ClosedBy
 
 class IndividualDebitCardDTO(object):
     def __init__(self, id: str, created_at: datetime, last_4_digits: str, expiration_date: str, status: CardStatus,
-                 shipping_address: Optional[Address], design: Optional[str], relationships: Optional[dict[str, Relationship]]):
+                 shipping_address: Optional[Address], design: Optional[str],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "individualDebitCard"
         self.attributes = {"createdAt": created_at, "last4Digits": last_4_digits, "expirationDate": expiration_date,
@@ -15,9 +16,11 @@ class IndividualDebitCardDTO(object):
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
+        shipping_address = Address.from_json_api(attributes.get("shippingAddress")) if attributes.get("shippingAddress") else None
         return IndividualDebitCardDTO(
-            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"], attributes["expirationDate"],
-            attributes["status"], attributes.get("shippingAddress"), attributes.get("design"), relationships
+            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"],
+            attributes["expirationDate"], attributes["status"],
+            shipping_address, attributes.get("design"), relationships
         )
 
 
@@ -26,7 +29,7 @@ class BusinessDebitCardDTO(object):
                  full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  status: CardStatus, passport: Optional[str], nationality: Optional[str],
                  shipping_address: Optional[Address], design: Optional[str],
-                 relationships: Optional[dict[str, Relationship]]):
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "businessDebitCard"
         self.attributes = {"createdAt": created_at, "last4Digits": last_4_digits, "expirationDate": expiration_date,
@@ -36,17 +39,20 @@ class BusinessDebitCardDTO(object):
         self.relationships = relationships
 
     def from_json_api(_id, _type, attributes, relationships):
+        shipping_address = Address.from_json_api(attributes.get("shippingAddress")) if attributes.get("shippingAddress") else None
         return BusinessDebitCardDTO(
-            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"], attributes["expirationDate"],
-            attributes["ssn"], attributes["fullName"], attributes["dateOfBirth"], attributes["address"], attributes["phone"],
-            attributes["email"], attributes["status"],  attributes.get("passport"), attributes.get("nationality"),
-            attributes.get("shippingAddress"), attributes.get("design"), relationships
+            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"],
+            attributes["expirationDate"], attributes["ssn"], FullName.from_json_api(attributes["fullName"]),
+            attributes["dateOfBirth"], Address.from_json_api(attributes["address"]),
+            Phone.from_json_api(attributes["phone"]), attributes["email"], attributes["status"],
+            attributes.get("passport"), attributes.get("nationality"),
+            shipping_address, attributes.get("design"), relationships
         )
 
 
 class IndividualVirtualDebitCardDTO(object):
     def __init__(self, id: str, created_at: datetime, last_4_digits: str, expiration_date: str, status: CardStatus,
-                 relationships: Optional[dict[str, Relationship]]):
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "individualVirtualDebitCard"
         self.attributes = {"createdAt": created_at, "last4Digits": last_4_digits, "expirationDate": expiration_date,
@@ -56,15 +62,16 @@ class IndividualVirtualDebitCardDTO(object):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return IndividualVirtualDebitCardDTO(
-            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"], attributes["expirationDate"],
-            attributes["status"], relationships
+            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"],
+            attributes["expirationDate"], attributes["status"], relationships
         )
 
 
 class BusinessVirtualDebitCardDTO(object):
     def __init__(self, id: str, created_at: datetime, last_4_digits: str, expiration_date: str, ssn: str,
-                 full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str, status: CardStatus,
-                 passport: Optional[str], nationality: Optional[str], relationships: Optional[dict[str, Relationship]]):
+                 full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
+                 status: CardStatus, passport: Optional[str], nationality: Optional[str],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "businessVirtualDebitCard"
         self.attributes = {"createdAt": created_at, "last4Digits": last_4_digits, "expirationDate": expiration_date,
@@ -75,9 +82,11 @@ class BusinessVirtualDebitCardDTO(object):
 
     def from_json_api(_id, _type, attributes, relationships):
         return BusinessVirtualDebitCardDTO(
-            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"], attributes["expirationDate"],
-            attributes["ssn"], attributes["fullName"], attributes["dateOfBirth"], attributes["address"], attributes["phone"],
-            attributes["email"], attributes["status"],  attributes.get("passport"), attributes.get("nationality"), relationships
+            _id, date_utils.to_datetime(attributes["createdAt"]), attributes["last4Digits"],
+            attributes["expirationDate"], attributes["ssn"], FullName.from_json_api(attributes["fullName"]),
+            attributes["dateOfBirth"], Address.from_json_api(attributes["address"]),
+            Phone.from_json_api(attributes["phone"]), attributes["email"], attributes["status"],
+            attributes.get("passport"), attributes.get("nationality"), relationships
         )
 
 
@@ -85,15 +94,16 @@ Card = Union[IndividualDebitCardDTO, BusinessDebitCardDTO, IndividualVirtualDebi
 
 
 class CreateIndividualDebitCard(object):
-    def __init__(self, relationships: dict[str, Relationship], shipping_address: Optional[Address] = None,
-                 design: Optional[str] = None, idempotency_key: Optional[str] = None, tags: Optional[dict[str, str]] = None):
+    def __init__(self, relationships: Dict[str, Relationship], shipping_address: Optional[Address] = None,
+                 design: Optional[str] = None, idempotency_key: Optional[str] = None,
+                 tags: Optional[Dict[str, str]] = None):
         self.shipping_address = shipping_address
         self.design = design
         self.idempotency_key = idempotency_key
         self.tags = tags
         self.relationships = relationships
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "individualDebitCard",
@@ -123,7 +133,7 @@ class CreateBusinessDebitCard(object):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  status: CardStatus, shipping_address: Optional[Address], ssn: Optional[str], passport: Optional[str],
                  nationality: Optional[str], design: Optional[str], idempotency_key: Optional[str],
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
         self.address = address
@@ -139,7 +149,7 @@ class CreateBusinessDebitCard(object):
         self.tags = tags
         self.relationships = relationships
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "businessDebitCard",
@@ -181,13 +191,13 @@ class CreateBusinessDebitCard(object):
         json.dumps(self.to_json_api())
 
 class CreateIndividualVirtualDebitCard(object):
-    def __init__(self, relationships: dict[str, Relationship], idempotency_key: Optional[str] = None,
-                 tags: Optional[dict[str, str]] = None):
+    def __init__(self, relationships: Dict[str, Relationship], idempotency_key: Optional[str] = None,
+                 tags: Optional[Dict[str, str]] = None):
         self.idempotency_key = idempotency_key
         self.tags = tags
         self.relationships = relationships
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "individualVirtualDebitCard",
@@ -211,8 +221,8 @@ class CreateIndividualVirtualDebitCard(object):
 class CreateBusinessVirtualDebitCard(object):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  status: CardStatus, ssn: Optional[str], passport: Optional[str], nationality: Optional[str],
-                 idempotency_key: Optional[str], tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+                 idempotency_key: Optional[str], tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
         self.address = address
@@ -226,7 +236,7 @@ class CreateBusinessVirtualDebitCard(object):
         self.tags = tags
         self.relationships = relationships
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "businessVirtualDebitCard",
@@ -262,16 +272,18 @@ class CreateBusinessVirtualDebitCard(object):
         json.dumps(self.to_json_api())
 
 
-CreateCardRequest = Union[CreateIndividualDebitCard, CreateBusinessDebitCard, CreateIndividualVirtualDebitCard, CreateBusinessVirtualDebitCard]
+CreateCardRequest = Union[CreateIndividualDebitCard, CreateBusinessDebitCard, CreateIndividualVirtualDebitCard,
+                          CreateBusinessVirtualDebitCard]
 
 class PatchIndividualDebitCard(object):
-    def __init__(self,card_id: str, shipping_address: Optional[Address] = None, design: Optional[str] = None, tags: Optional[dict[str, str]] = None):
+    def __init__(self,card_id: str, shipping_address: Optional[Address] = None, design: Optional[str] = None,
+                 tags: Optional[Dict[str, str]] = None):
         self.card_id = card_id
         self.shipping_address = shipping_address
         self.design = design
         self.tags = tags
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "individualDebitCard",
@@ -297,13 +309,13 @@ class PatchIndividualDebitCard(object):
 class PatchBusinessDebitCard(object):
     def __init__(self, card_id: str, shipping_address: Optional[Address] = None, address: Optional[Address] = None,
                  phone: Optional[Phone] = None, email: Optional[str] = None, design: Optional[str] = None,
-                 tags: Optional[dict[str, str]] = None):
+                 tags: Optional[Dict[str, str]] = None):
         self.card_id = card_id
         self.shipping_address = shipping_address
         self.design = design
         self.tags = tags
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "businessDebitCard",
@@ -335,11 +347,11 @@ class PatchBusinessDebitCard(object):
         json.dumps(self.to_json_api())
 
 class PatchIndividualVirtualDebitCard(object):
-    def __init__(self, card_id: str, tags: Optional[dict[str, str]] = None):
+    def __init__(self, card_id: str, tags: Optional[Dict[str, str]] = None):
         self.card_id = card_id
         self.tags = tags
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "individualVirtualDebitCard",
@@ -356,15 +368,15 @@ class PatchIndividualVirtualDebitCard(object):
         json.dumps(self.to_json_api())
 
 class PatchBusinessVirtualDebitCard(object):
-    def __init__(self, card_id: str, address: Optional[Address] = None, phone: Optional[Phone] = None, email: Optional[str] = None,
-                 tags: Optional[dict[str, str]] = None):
+    def __init__(self, card_id: str, address: Optional[Address] = None, phone: Optional[Phone] = None,
+                 email: Optional[str] = None, tags: Optional[Dict[str, str]] = None):
         self.card_id = card_id
         self.address = address
         self.phone = phone
         self.email = email
         self.tags = tags
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "businessVirtualDebitCard",
@@ -389,13 +401,14 @@ class PatchBusinessVirtualDebitCard(object):
     def __repr__(self):
         json.dumps(self.to_json_api())
 
-PatchCardRequest = Union[PatchIndividualDebitCard, PatchBusinessDebitCard, PatchIndividualVirtualDebitCard, PatchBusinessVirtualDebitCard]
+PatchCardRequest = Union[PatchIndividualDebitCard, PatchBusinessDebitCard, PatchIndividualVirtualDebitCard,
+                         PatchBusinessVirtualDebitCard]
 
 class ReplaceCardRequest(object):
     def __init__(self, shipping_address: Optional[Address] = None):
         self.shipping_address = shipping_address
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "replaceCard",
